#ifndef _EFL_UI_BOX_EO_H_
#define _EFL_UI_BOX_EO_H_

#ifndef _EFL_UI_BOX_EO_CLASS_TYPE
#define _EFL_UI_BOX_EO_CLASS_TYPE

typedef Eo Efl_Ui_Box;

#endif

#ifndef _EFL_UI_BOX_EO_TYPES
#define _EFL_UI_BOX_EO_TYPES


#endif
/** Efl UI box class
 *
 * @ingroup Efl_Ui_Box
 */
#define EFL_UI_BOX_CLASS efl_ui_box_class_get()

EWAPI const Efl_Class *efl_ui_box_class_get(void);

#endif
